@@ -140,8 +140,10 @@ class SearchPopover(Gtk.Popover):
         """
         # FIXME Not needed with GTK >= 3.18
         App().window.enable_global_shortcuts(False)
-        height = App().window.get_size()[1]
-        self.set_size_request(450, height * 0.7)
+        window_size = App().window.get_size()
+        height = window_size[1]
+        width = min(500, window_size[0])
+        self.set_size_request(width, height * 0.7)
 
     def __on_unmap(self, widget):
         """
