@@ -31,8 +31,6 @@ class ToolbarInfo(Gtk.Bin, InfoController):
         builder = Gtk.Builder()
         builder.add_from_resource("/org/gnome/Lollypop/ToolbarInfo.ui")
         builder.connect_signals(self)
-        self.__pop_tunein = None
-        self.__pop_info = None
         self.__timeout_id = None
         self.__width = 0
 
@@ -126,14 +124,15 @@ class ToolbarInfo(Gtk.Bin, InfoController):
             Show current track menu
             @param args as []
         """
+        from lollypop.pop_menu import ToolbarMenu
+        menu = ToolbarMenu(App().player.current_track)
         if App().player.current_track.id >= 0:
-            from lollypop.pop_menu import PlaylistsMenu
             from lollypop.pop_menu import TrackMenuPopover
-            popover = TrackMenuPopover(
-                App().player.current_track,
-                PlaylistsMenu(App().player.current_track))
+            popover = TrackMenuPopover(App().player.current_track, menu)
             popover.set_relative_to(self._infobox)
-            popover.show()
+        elif App().player.current_track.id == Type.RADIOS:
+            popover = Gtk.Popover.new_from_model(self._infobox, menu)
+        popover.show()
 
     def __on_info_short(self, args):
         """
@@ -142,21 +141,18 @@ class ToolbarInfo(Gtk.Bin, InfoController):
         """
         if App().player.current_track.id == Type.EXTERNALS:
             from lollypop.pop_externals import ExternalsPopover
-            expopover = ExternalsPopover()
-            expopover.set_relative_to(self._infobox)
-            expopover.populate()
-            expopover.show()
+            popover = ExternalsPopover()
+            popover.populate()
+        elif App().player.current_track.id == Type.RADIOS:
+            from lollypop.pop_tunein import TuneinPopover
+            popover = TuneinPopover()
+            popover.populate()
         elif App().player.current_track.id is not None:
-            if self.__pop_info is None:
-                from lollypop.pop_info import InfoPopover
-                self.__pop_info = InfoPopover([])
-                self.__pop_info.set_relative_to(self._infobox)
-            if App().player.current_track.id == Type.RADIOS:
-                view_type = Type.RADIOS
-            else:
-                view_type = Type.ALBUMS
-            self.__pop_info.set_view_type(view_type)
-            self.__pop_info.show()
+            from lollypop.pop_information import InformationPopover
+            popover = InformationPopover()
+            popover.populate(App().player.current_track.artist_ids)
+        popover.set_relative_to(self._infobox)
+        popover.show()
 
     def __on_loading_changed(self, player, show):
         """
