@@ -10,14 +10,50 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-from gi.repository import Gio, GLib
+from gi.repository import Gio, GLib, Gdk
 
+from math import pi
 from gettext import gettext as _
 import unicodedata
 
 from lollypop.define import App
 
 
+def draw_rounded_image(image, ctx):
+    """
+        Draw rounded image
+        @param image as Gtk.Image
+        @param ctx as cairo.Context
+        @param size as int
+    """
+    if not image.is_drawable():
+        return
+    surface = None
+    if image.props.surface is None:
+        pixbuf = image.get_pixbuf()
+        if pixbuf is not None:
+            surface = Gdk.cairo_surface_create_from_pixbuf(
+                pixbuf,
+                image.get_scale_factor(),
+                None)
+    else:
+        surface = image.props.surface
+    if surface is not None:
+        width = surface.get_width() - 4
+        ctx.translate(2, 2)
+        ctx.new_sub_path()
+        radius = width / 2
+        ctx.arc(width / 2, width / 2, radius, 0, 2 * pi)
+        ctx.set_source_rgb(1, 1, 1)
+        ctx.fill_preserve()
+        ctx.set_line_width(2)
+        ctx.set_source_rgba(0, 0, 0, 0.3)
+        ctx.stroke_preserve()
+        ctx.set_source_surface(surface, 0, 0)
+        ctx.clip()
+        ctx.paint()
+
+
 def set_proxy_from_gnome():
     """
         Set proxy settings from GNOME
