@@ -70,9 +70,13 @@ class LyricsView(View):
             lyrics = reader.get_lyrics(tags)
         if lyrics:
             self.__lyrics_label.set_label(lyrics)
-        else:
+            self.__lyrics_label.show()
+        elif App().settings.get_value("network-access"):
             self.__download_wikia_lyrics()
             self.__download_genius_lyrics()
+        else:
+            self.__lyrics_label.set_label(_("Network access disabled"))
+            self.__lyrics_label.show()
 
 ##############
 # PROTECTED  #
@@ -158,11 +162,11 @@ class LyricsView(View):
         context.add_class("lyrics")
         width = self.get_allocated_width()
         if width > WindowSize.XXLARGE:
-            context.add_class("lyrics-xx-large")
-        elif width > WindowSize.MONSTER:
             context.add_class("lyrics-x-large")
-        elif width > WindowSize.BIG:
+        elif width > WindowSize.MONSTER:
             context.add_class("lyrics-large")
+        elif width > WindowSize.BIG:
+            context.add_class("lyrics-medium")
 
     def __on_lyrics_downloaded(self, uri, status, data, cls, separator):
         """
